
import React from 'react';
import { motion } from 'framer-motion';

const ReferenceLogo = ({ imageText, altText, url }) => (
  <motion.div
    className="p-4 bg-white/10 backdrop-blur-sm rounded-lg flex items-center justify-center h-24 md:h-32 transition-all duration-300 hover:bg-white/20"
    whileHover={{ scale: 1.05, boxShadow: "0px 10px 20px rgba(0,0,0,0.1)" }}
  >
    <a href={url || '#'} target="_blank" rel="noopener noreferrer">
      <img  class="max-h-12 md:max-h-16 object-contain" alt={altText} src="https://images.unsplash.com/photo-1697256200022-f61abccad430" />
    </a>
  </motion.div>
);

const ReferencesSection = () => {
  const references = [
    { imageText: "TEDx Logo", altText: "TEDx" },
    { imageText: "LUX* Resorts Logo", altText: "LUX*" },
    { imageText: "GRIT Logo", altText: "GRIT" },
    { imageText: "TOMS Logo", altText: "TOMS" },
    { imageText: "Party.Space Logo", altText: "Party.Space" },
    { imageText: "Shopify Logo", altText: "Shopify" },
    { imageText: "Starbucks Logo", altText: "Starbucks" },
    { imageText: "KFC Logo", altText: "KFC" },
    { imageText: "WWF Logo", altText: "WWF" },
    { imageText: "Greenpeace Logo", altText: "Greenpeace" },
    { imageText: "Lipton Logo", altText: "Lipton" },
    { imageText: "McDonalds Logo", altText: "McDonalds" },
  ];

  return (
    <section id="references" className="py-16 md:py-24 bg-gradient-to-br from-purple-800 via-pink-700 to-orange-600">
      <div className="container mx-auto px-4">
        <motion.h2
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.6 }}
          className="text-4xl md:text-5xl font-bold text-center text-yellow-400 mb-16"
        >
          Bize Güvenen Markalar
        </motion.h2>
        <div className="grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-6 gap-6 md:gap-8">
          {references.map((ref, index) => (
            <motion.div
              key={index}
              initial={{ opacity: 0, scale: 0.8 }}
              whileInView={{ opacity: 1, scale: 1 }}
              viewport={{ once: true }}
              transition={{ duration: 0.5, delay: index * 0.05 }}
            >
              <ReferenceLogo imageText={ref.imageText} altText={ref.altText} />
            </motion.div>
          ))}
        </div>
      </div>
    </section>
  );
};

export default ReferencesSection;
